
#ifndef __XINEI18N_H
#define __XINEI18N_H



#include "xineCommon.h"



namespace PluginXine
{

  static const tI18nPhrase Phrases[] = {
    { "Software based playback using xine",
      "Software-basierte Wiedergabe mittels xine",
      "",// TODO
      "Software per riproduzione tramite xine",
      "Software-gebaseerde weergave met behulp van Xine",
      "",// TODO
      "",// TODO
      "",// TODO
      "Xine-nyttlaite",
      "",// TODO
      "",// TODO
      "",// TODO
      "Mjukvarubaserad uppspelning med xine",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Live-TV SD video buffer [frames]",
      "SD-Video Puffer fr Live-TV [Bilder]",
      "",// TODO
      "Buffer TV dal vivo [frames]",
      "Live-TV buffer [frames]",
      "",// TODO
      "",// TODO
      "",// TODO
      "TV-lhetyksen puskurointi [ruutua]",
      "",// TODO
      "",// TODO
      "",// TODO
      "Live-TV bufferstorlek [bildrutor]",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Live-TV HD video buffer [frames]",
      "HD-Video Puffer fr Live-TV [Bilder]",
      "",// TODO
      "Buffer TV dal vivo [frames]",
      "Live-TV buffer [frames]",
      "",// TODO
      "",// TODO
      "",// TODO
      "TV-lhetyksen puskurointi [ruutua]",
      "",// TODO
      "",// TODO
      "",// TODO
      "Live-TV bufferstorlek [bildrutor]",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Live-TV audio buffer [frames]",
      "Audio Puffer fr Live-TV [Bilder]",
      "",// TODO
      "Buffer TV dal vivo [frames]",
      "Live-TV buffer [frames]",
      "",// TODO
      "",// TODO
      "",// TODO
      "TV-lhetyksen puskurointi [ruutua]",
      "",// TODO
      "",// TODO
      "",// TODO
      "Live-TV bufferstorlek [bildrutor]",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Buffer hysteresis [frames]",
      "Puffer-Hysterese [Bilder]",
      "",// TODO
      "Buffer isteresi [frames]",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "Puskurin hystereesis [ruutua]",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Buffer monitoring duration [s]",
      "Puffer-berwachungsdauer [s]",
      "",// TODO
      "Durata monitoraggio buffer [s]",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "Puskurin monitoroinnin kesto [s]",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Buffer monitoring mode",
      "Puffer-berwachungsmodus",
      "",// TODO
      "Modalit monitoraggio buffer",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "Puskurin monitorointitapa",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Once",
      "Einmal",
      "",// TODO
      "Una volta",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "kerran",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Continuous",
      "Durchgehend",
      "",// TODO
      "Continuo",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "jatkuva",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "OSD display mode",
      "Anzeigeart fr OSD",
      "",// TODO
      "Modalit visualizzazione OSD",
      "Weergave-type van de OSD",
      "",// TODO
      "",// TODO
      "",// TODO
      "Kuvaruutunytn moodi",
      "",// TODO
      "",// TODO
      "",// TODO
      "OSD lge",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "X11 overlay",
      "berlagern (X11)",
      "",// TODO
      "Overlay (X11)",
      "X11 overlay",
      "",// TODO
      "",// TODO
      "",// TODO
      "overlay (X11)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Blend clipped",
      "Abschneiden",
      "",// TODO
      "Trasparenza fissa",
      "Samenvoegen met afsnijden",
      "",// TODO
      "",// TODO
      "",// TODO
      "leikattu",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Blend scaled LQ",
      "Einpassen LQ",
      "",// TODO
      "Trasparenza scalata LQ",
      "Samenvoegen met lage kwaliteit",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalattu (LQ)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Blend scaled HQ",
      "Einpassen HQ",
      "",// TODO
      "Trasparenza scalata HQ",
      "Samenvoegen met hoge kwaliteit",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalattu (HQ)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Blend scaled SHQ",
      "Einpassen SHQ",
      "",// TODO
      "Trasparenza scalata SHQ",
      "Samenvoegen met superhoge kwaliteit",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalattu (SHQ)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Blend scaled Auto",
      "Einpassen Auto",
      "",// TODO
      "Trasparenza scalata in automatico",
      "Automatische samenvoeg-modus",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalattu (auto)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "OSD gamma correction [ 123 => 1.23 ]",
      "OSD Gamma Korrektur [ 123 => 1.23 ]",
      "",// TODO
      "Correzione gamma OSD [ 123 => 1.23 ]",
      "OSD gamma correctie [ 123 => 1.23 ]",
      "",// TODO
      "",// TODO
      "",// TODO
      "Kuvaruutunytn gammakorjaus [123 => 1.23]",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Audio mode",
      "Audio-Modus",
      "",// TODO
      "Modalit audio",
      "Audio-modus",
      "",// TODO
      "",// TODO
      "",// TODO
      "Monikanavanet (Dolby)",
      "",// TODO
      "",// TODO
      "",// TODO
      "Ljud lge",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Dolby off",
      "Dolby aus",
      "",// TODO
      "Dolby disattivo",
      "Dolby uitgeschakeld",
      "",// TODO
      "",// TODO
      "",// TODO
      "pois",
      "",// TODO
      "",// TODO
      "",// TODO
      "Dolby av",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Dolby on",
      "Dolby ein",
      "",// TODO
      "Dolby attivo",
      "Dolby ingeschakeld",
      "",// TODO
      "",// TODO
      "",// TODO
      "pll",
      "",// TODO
      "",// TODO
      "",// TODO
      "Dolby p",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Control xine's volume",
      "Lautstrke in xine steuern",
      "",// TODO
      "Regolazione volume xine",
      "Xine's volume via VDR besturen",
      "",// TODO
      "",// TODO
      "",// TODO
      "Kyt Xinen nenvoimakkuusst",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "No",
      "Nein",
      "",// TODO
      "No",
      "Nee",
      "",// TODO
      "",// TODO
      "",// TODO
      "ei",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Yes",
      "Ja",
      "",// TODO
      "S",
      "Ja",
      "",// TODO
      "",// TODO
      "",// TODO
      "kyll",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Muting",
      "Stummschalten",
      "",// TODO
      "Muto",
      "Geluid dempen",
      "",// TODO
      "",// TODO
      "",// TODO
      "Mykistys",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Ignore",
      "Ignorieren",
      "",// TODO
      "Ignora",
      "Negeren",
      "",// TODO
      "",// TODO
      "",// TODO
      "sivuuta",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Simulate",
      "Simulieren",
      "",// TODO
      "Simula",
      "Simuleren",
      "",// TODO
      "",// TODO
      "",// TODO
      "simuloi",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Execute",
      "Ausfhren",
      "",// TODO
      "Esegui",
      "Uitvoeren",
      "",// TODO
      "",// TODO
      "",// TODO
      "suorita",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Get primary device when xine connects",
      "Automatisch zum primren Interface werden",
      "",// TODO
      "Mostra interfaccia primaria all'avvio di xine",
      "Xine als primair dvb-apparaat gebruiken",
      "",// TODO
      "",// TODO
      "",// TODO
      "Kyt automaattisesti ensisijaisena sovittimena",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Support semi transparent colors",
      "Untersttzung fr halbtransparente Farben",
      "",// TODO
      "Supporto colori semi trasparenti",
      "Ondersteun semi-transparante kleuren",
      "",// TODO
      "",// TODO
      "",// TODO
      "Tue puolilpinkyvi vrej",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Switching primary DVB to %s...", // %s will be substituted by the plugin name, i. e. 'xine'.
      "Primres Interface wird zu %s umgeschaltet...",
      "", // TODO "Preklapljanje primarne DVB naprave...",
      "Cambio scheda DVB primaria a %s...",
      "", // TODO "Eerste DVB-kaart wordt omgeschakeld...",
      "", // TODO "A mudar interface DVB primrio...",
      "", // TODO "Changement de carte DVB primaire...",
      "", // TODO "Bytter frste DVB-enhet...",
      "Vaihdetaan ensisijaiseksi DVB-sovittimeksi %s...",
      "", // TODO "Prz곱czam na pierwszy interfejs DVB...",
      "", // TODO "Cambiando el interfaz DVB primario...",
      "", // TODO "  DVB  ...",
      "", // TODO "Byter primr DVB enhet...",
      "", // TODO "Comut dispozitiv DVB primar...",
      "", // TODO "Primr Interface tkapcsolva...",
      "", // TODO "Canviant a la interfcie DVB primria...",
#if APIVERSNUM >= 10302
      "", // TODO "  DVB-...",
#if APIVERSNUM >= 10307
      "", // TODO "Preklapanje primarnog DVB ureaja...",
#if APIVERSNUM >= 10313
      "", // TODO "Esmase DVB seadme mberllitus...",
#if APIVERSNUM >= 10316
      "", // TODO "Skifter primr DVB enhed...",
#if APIVERSNUM >= 10342
      "", // TODO "Pepnout primrn DVB...",
#endif
#endif
#endif
#endif
#endif
    },    
    { "Switched primary DVB back from %s", // %s will be substituted by the plugin name, i. e. 'xine'.
      "Primres Interface wurde von %s zurckgeschaltet",
      "", // TODO "Preklapljanje primarne DVB naprave",
      "Ritorno a scheda DVD primaria da %s",
      "", // TODO "Eerste DVB-kaart wordt omgeschakeld",
      "", // TODO "A mudar interface DVB primrio",
      "", // TODO "Changement de carte DVB primaire",
      "", // TODO "Bytter frste DVB-enhet",
      "Ensisijainen DVB-sovitin vaihdettu takaisin %s:st",
      "", // TODO "Prz곱czam na pierwszy interfejs DVB",
      "", // TODO "Cambiando el interfaz DVB primario",
      "", // TODO "  DVB  ",
      "", // TODO "Byter primr DVB enhet",
      "", // TODO "Comut dispozitiv DVB primar",
      "", // TODO "Primr Interface tkapcsolva",
      "", // TODO "Canviant a la interfcie DVB primria",
#if APIVERSNUM >= 10302
      "", // TODO "  DVB-",
#if APIVERSNUM >= 10307
      "", // TODO "Preklapanje primarnog DVB ureaja",
#if APIVERSNUM >= 10313
      "", // TODO "Esmase DVB seadme mberllitus",
#if APIVERSNUM >= 10316
      "", // TODO "Skifter primr DVB enhed",
#if APIVERSNUM >= 10342
      "", // TODO "Pepnout primrn DVB",
#endif
#endif
#endif
#endif
#endif
    },    
    { "Yes (by hardware)",
      "Ja (in Hardware)",
      "",// TODO
      "S (tramite hardware)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Yes (by software)",
      "Ja (in Software)",
      "",// TODO
      "S (tramite software)",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "4:3 image zoom X [%]",
      "4:3 Bilder X-Skalierung [%]",
      "",// TODO
      "Ingrandimento X [%] immagine 4:3",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "4:3 image zoom Y [%]",
      "4:3 Bilder Y-Skalierung [%]",
      "",// TODO
      "Ingrandimento Y [%] immagine 4:3",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "16:9 image zoom X [%]",
      "16:9 Bilder X-Skalierung [%]",
      "",// TODO
      "Ingrandimento X [%] immagine 16:9",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "16:9 image zoom Y [%]",
      "16:9 Bilder Y-Skalierung [%]",
      "",// TODO
      "Ingrandimento Y [%] immagine 16:9",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Connection interacts with EIT scanner",
      "Verbindung interagiert mit EIT-Scanner",
      "",// TODO
      "La connessione interagisce con lo scanner EIT",
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
/*    
    { "Replay prebuffer [frames]",
      "Vorpuffer fr Wiedergabe [Bilder]",
      "",// TODO
      "Riproduci prebuffer [frames]",
      "Pre-buffer voor afspelen van opnamen",
      "",// TODO
      "",// TODO
      "",// TODO
      "Toiston puskurointi [ruutua]",
      "",// TODO
      "",// TODO
      "",// TODO
      "Uppspelningsbuffer [bildrutor]",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Default settings optimized for",
      "Standard-Einstellungen optimiert fr",
      "",// TODO
      "Impostazioni predefinite ottimizzate per",
      "Standaard instellingen geoptimaliseerd voor",
      "",// TODO
      "",// TODO
      "",// TODO
      "Oletusasetukset optimoitu",
      "",// TODO
      "",// TODO
      "",// TODO
      "Standardinstllning optimerad fr",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Live-TV",
      "Live-TV",
      "",// TODO
      "TV dal vivo",
      "Live-TV",
      "",// TODO
      "",// TODO
      "",// TODO
      "TV-lhetykselle",
      "",// TODO
      "",// TODO
      "",// TODO
      "Live-TV",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Replay",
      "Wiedergabe",
      "",// TODO
      "Riproduci",
      "Opnamen afspelen",
      "",// TODO
      "",// TODO
      "",// TODO
      "toistolle",
      "",// TODO
      "",// TODO
      "",// TODO
      "Uppspelning",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Scaled",
      "Skaliert",
      "",// TODO
      "Scalato",
      "Geschaald",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalattu",
      "",// TODO
      "",// TODO
      "",// TODO
      "Skalad",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Unscaled",
      "Unskaliert",
      "",// TODO
      "Non scalato",
      "Ongeschaald",
      "",// TODO
      "",// TODO
      "",// TODO
      "skaalamaton",
      "",// TODO
      "",// TODO
      "",// TODO
      "Normal",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },
    { "Settings are now optimized for 'Replay'",
      "Einstellungen nun optimiert fr 'Wiedergabe'",
      "",// TODO
      "Ora le impostazioni sono ottimizzate per la 'Riproduzione'",
      "Instellingen zijn nu geoptimaliseerd voor 'Opnamen afspelen'",
      "",// TODO
      "",// TODO
      "",// TODO
      "Asetukset optimoitu toistolle",
      "",// TODO
      "",// TODO
      "",// TODO
      "Instllningarna r nu optimerade fr 'Uppspelning'",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "Settings are now optimized for 'Live-TV'",
      "Einstellungen nun optimiert fr 'Live-TV'",
      "",// TODO
      "Ora le impostazioni sono ottimizzate per la 'TV dal vivo'",
      "Instellingen zijn nu geoptimaliseerd voor 'Live-TV'",
      "",// TODO
      "",// TODO
      "",// TODO
      "Asetukset optimoitu TV-lhetykselle",
      "",// TODO
      "",// TODO
      "",// TODO
      "Instllningarna r nu optimerade fr 'Live-TV'",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "xine - Choose optimized settings for 'Live-TV'",
      "xine - Whle optimierte Einstellungen fr 'Live-TV'",
      "",// TODO
      "xine - Scegli impostazioni ottimizzate per la 'TV dal vivo'",
      "xine - Kies optimale instellingen voor 'Live-TV'",
      "",// TODO
      "",// TODO
      "",// TODO
      "xine - Valitse optimoidut asetukset TV-lhetykselle",
      "",// TODO
      "",// TODO
      "",// TODO
      "xine - Vlj optimerade instllningar fr 'Live-TV'",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
    { "xine - Choose optimized settings for 'Replay'",
      "xine - Whle optimierte Einstellungen fr 'Wiedergabe'",
      "",// TODO
      "xine - Scegli impostazioni ottimizzate per la 'Riproduzione'",
      "xine - Kies optimale instellingen voor 'Opnamen afspelen'",
      "",// TODO
      "",// TODO
      "",// TODO
      "xine - Valitse optimoidut asetukset toistolle",
      "",// TODO
      "",// TODO
      "",// TODO
      "xine - Vlj optimerade instllningar fr 'Live-TV'",
      "",// TODO
      "",// TODO
      "",// TODO
#if APIVERSNUM >= 10302
      "",// TODO
#if APIVERSNUM >= 10307
      "",// TODO
#if APIVERSNUM >= 10313
      "",// TODO
#if APIVERSNUM >= 10316
      "",// TODO
#if APIVERSNUM >= 10342
      "",// TODO
#endif
#endif
#endif
#endif
#endif
    },    
*/
    { NULL }
  };

};



#endif //__XINEI18N_H

